@@ -782,6 +782,7 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
         """The config was changed and now needs to be saved and reloaded"""
         apt.apt_pkg.init_config()
         self.button_revert.set_sensitive(True)
+        self.modified_sourceslist = True
 
     def on_keys_modified(self):
         """ The apt keys have changed and need to be redisplayed """
@@ -794,6 +795,7 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
         self.show_isv_sources()
         self.show_cdrom_sources()
         self.button_revert.set_sensitive(True)
+        self.modified_sourceslist = True
 
     def on_auth_failed(self):
         """ send when the authentication failed """
@@ -1087,7 +1089,7 @@ class SoftwarePropertiesGtk(SoftwareProperties, SimpleGtkbuilderApp):
         self.clear_changes()
 
     def on_driver_restart_clicked(self, button_restart):
-        subprocess.call(['/usr/lib/indicator-session/gtk-logout-helper', '--restart'])
+        subprocess.call(['gnome-session-quit', '--reboot'])
 
     def clear_changes(self):
         self.orig_selection = {}
